#!/bin/bash

run_test () {
  query="$1"
  for i in 0 1 2 4 8 16 32 64 128 256 512 1000 ; do
    service postgresql restart
    sync; echo 3 > /proc/sys/vm/drop_caches; sleep 5
    psql testdb -e -c "set effective_io_concurrency=$i; set enable_indexscan=off; set enable_seqscan=off; explain (analyze, buffers) $query;"
  done
}

createdb testdb

psql testdb -e -c "create table test as select generate_series(1, 100000) id, repeat('x', 750) val;"
psql testdb -e -c "create index sparse_idx on test (((id%100)=0));"

psql testdb -e -c "select count(*) tup_per_page from test group by (ctid::text::point)[0] order by count(*) desc limit 5;"

run_test "select * from test where ((id%100)=0) and val != ''" >test11.txt
run_test "select * from test where ((id%100)=0) and val != ''" >test12.txt
run_test "select * from test where ((id%100)=0) and val != ''" >test13.txt

psql testdb -e -c "select version();" >summary.txt

grep -E "effective_io_concurrency|Execution time" test11.txt | perl -p -e 's/.*(effective_io_concurrency=[0-9]+).*\n/\1/' >>summary.txt; echo "" >>summary.txt
grep -E "effective_io_concurrency|Execution time" test12.txt | perl -p -e 's/.*(effective_io_concurrency=[0-9]+).*\n/\1/' >>summary.txt; echo "" >>summary.txt
grep -E "effective_io_concurrency|Execution time" test13.txt | perl -p -e 's/.*(effective_io_concurrency=[0-9]+).*\n/\1/' >>summary.txt; echo "" >>summary.txt

dropdb testdb
